@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2018 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -50,6 +50,13 @@ create a log object. Do not use it directly, instead use:
 
 =cut
 
+my %LogLevel = (
+    error  => 16,
+    notice => 8,
+    info   => 4,
+    debug  => 2,
+);
+
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -58,7 +65,7 @@ sub new {
     bless( $Self, $Type );
 
     if ( !$Kernel::OM ) {
-        Carp::confess('$Kernel::OM is not defined, please initialize your object manager');
+        Carp::confess('$Kernel::OM is not defined, please initialize your object manager')
     }
 
     my $ConfigObject = $Kernel::OM->Get('Kernel::Config');
@@ -72,6 +79,11 @@ sub new {
     $Self->{LogPrefix} = $Param{LogPrefix} || '?LogPrefix?';
     $Self->{LogPrefix} .= '-' . $SystemID;
 
+    # configured log level (debug by default)
+    $Self->{MinimumLevel}    = $ConfigObject->Get('MinimumLogLevel') || 'debug';
+    $Self->{MinimumLevel}    = lc $Self->{MinimumLevel};
+    $Self->{MinimumLevelNum} = $LogLevel{ $Self->{MinimumLevel} };
+
     # load log backend
     my $GenericModule = $ConfigObject->Get('LogModule') || 'Kernel::System::Log::SysLog';
     if ( !eval "require $GenericModule" ) {    ## no critic
@@ -138,9 +150,13 @@ See for more info L<http://en.wikipedia.org/wiki/Syslog#Severity_levels>
 sub Log {
     my ( $Self, %Param ) = @_;
 
-    my $Priority = $Param{Priority} || 'debug';
-    my $Message  = $Param{MSG}      || $Param{Message} || '???';
-    my $Caller   = $Param{Caller}   || 0;
+    my $Priority    = lc $Param{Priority}  || 'debug';
+    my $PriorityNum = $LogLevel{$Priority} || $LogLevel{debug};
+
+    return 1 if $PriorityNum < $Self->{MinimumLevelNum};
+
+    my $Message = $Param{MSG} || $Param{Message} || '???';
+    my $Caller = $Param{Caller} || 0;
 
     # returns the context of the current subroutine and sub-subroutine!
     my ( $Package1, $Filename1, $Line1, $Subroutine1 ) = caller( $Caller + 0 );
@@ -290,7 +306,7 @@ sub CleanUp {
     # remove the shm
     if ( !shmctl( $Self->{Key}, 0, 0 ) ) {
         $Self->Log(
-            Priority => 'error',
+            Priority => 'notice',
             Message  => "Can't remove shm for log: $!",
         );
         return;
