@@ -191,6 +191,13 @@ sub _Fetch {
             }
             else {
 
+                # safety protection
+                my $FetchDelay = ( $FetchCounter % 20 == 0 ? 1 : 0 );
+                if ( $FetchDelay && $CMD ) {
+                    print "$AuthType: Safety protection: waiting 1 second before processing next mail...\n";
+                    sleep 1;
+                }
+
                 # get message (header and body)
                 my $Message = $IMAPObject->message_string($Messageno);
 
